import javax.swing.*;
import java.util.ArrayList;

/**
 * This class defines an player in a "connect 4 game". It includes the name
 * of the player, as well as instance variables needed to create a Piece 
 * object, including a symbol and an image. Has various methods for accessing
 * and comparing its members.
 * @author Kenneth Marino
 * @version 1.0 3/14/2012
 */
public class Player
{
	// Instance variables
	private String name;
	private char symbol;
	private ImageIcon icon;
	
	// Static variables
	private static ArrayList<Character> usedSymbols = new ArrayList<Character>();
	
	/**
	 * Constructor. Sets the symbol and image of the piece for the player, as
	 * well as the name of the player. Does the work of ensuring that the Piece
	 * object created is distinct from any others created before.
	 * @param name The name of the player
	 * @param symbol The symbol representing the piece
	 * @param icon The image representing the piece
	 */
	public Player(String name, char symbol, ImageIcon icon)
	{
		// Adds the empty piece when the Player constructor is first called
		if (usedSymbols.isEmpty())
			usedSymbols.add(Piece.EMPTY_PIECE);
		// Sets the name
		this.name = name;
		// If the symbol is already in use
		if (usedSymbols.contains(symbol) || symbol == '*')
		{
			// Loop from 'A' on until it finds an unused symbol
			char newSymbol = 'A';
			while(usedSymbols.contains(newSymbol))
			{
				newSymbol++;
			}
			this.symbol = newSymbol;
			usedSymbols.add(newSymbol);
		}
		else
		{
			// Otherwise add the name
			this.symbol = symbol;
			usedSymbols.add(symbol);
		}
		// Adds the icon 
		this.icon = icon;
	}
	
	/**
	 * This method instantiates a new Piece for the player.
	 * @return A Piece object corresponding to the player
	 */
	public Piece addPiece()
	{
		return new Piece(symbol, icon);
	}
	
	/**
	 * This method returns a String representation of the object,
	 * in this case, the player's name. 
	 * @return String representation
	 */
	public String toString()
	{
		return name;
	}
}