import java.util.Scanner;

/**
 * This class defines the text-baded UI in a "connect 4 game". The main method
 * handles the user input, the text output and keeps the state objects associated
 * with the game and iteracts with them (ie Board Piece). Also has a helper method
 * to print the state of the board.
 * @author Kenneth Marino
 * @version 1.0 3/14/2012
 */
public class Text4
{
	/**
	 * The main method creates the board, and loops continually until the game is over. On each
	 * move, accepts user input, creates the correct Piece method and calls the turn method on Board. 
	 * When the game is over, prompts the user to play a new game, and displays the winner when a
	 * game ends. 
	 * @param args Command line arguments (unused)
	 */
	public static void main(String[] args)
	{
		// Create a new scanner object for input
		Scanner scan = new Scanner(System.in);
		
		// Promps
		System.out.print("Please enter Player 1's name: ");
		String p1Name = scan.nextLine();
		System.out.print("Please enter Player 2's name: ");
		String p2Name = scan.nextLine();
		System.out.print("Please enter Player 1's symbol as a character: ");
		char p1Char = scan.next().charAt(0);
		System.out.print("Please enter Player 2's symbol as a character: ");
		char p2Char = scan.next().charAt(0);
		
		// Create the Players and the board
		Player player1 = new Player(p1Name, p1Char, null);
		Player player2 = new Player(p2Name, p2Char, null);
		Board board = new Board();
		
		// Loops over games
		char continueOption;
		do
		{
			boolean isWin;
			// Start with player 1
			boolean p1Turn = true; 
			// Game loop
			do
			{
				// Display the current board
				printBoard(board);
				
				// Get current player info
				Player curPlayer;
				if (p1Turn)
					curPlayer = player1;
				else
					curPlayer = player2;
					
				// Print the request for input and get column number
				System.out.println(curPlayer + " enter a column number:");
				int colNum = scan.nextInt();
				
				// Make the move
				boolean success = board.move(colNum-1, curPlayer.addPiece());
				
				// If it failed, print an error message
				if (!success)
				{
					System.out.println("Invalid selection. Please try again");
					p1Turn = !p1Turn;
				}
				else
				{
					Piece[][] pieces = board.getState();
					if (pieces[Board.ROWS-1][colNum-1] == null)
						System.out.println("Column " + colNum + " dropped!"); 
				}
				
				// Check for a win
				isWin = board.checkForWin();
				if (isWin)
				{
					printBoard(board);
					System.out.println("Congratulations " + curPlayer + ", you won!");
				}
				
				// Switch players
				p1Turn = !p1Turn;
				
			}while(!isWin);
			
			// Ask if the user wants to play again
			System.out.print("Play again? ('y' = yes): ");
			continueOption = scan.next().charAt(0);
			
			// Reset the board and clear the buffer
			board.reset();
			scan.nextLine();
			
		}while(continueOption == 'y');
	}
	
	/**
	 * This method prints the current state of the board. Uses getState to
	 * get the array of pieces, and prints the appropriate characters for
	 * each piece or null reference.
	 * @param board The game board to print
	 */
	public static void printBoard(Board board)
	{
		// Get the state of the board
		Piece[][] pieces = board.getState();
		// Loop through each column and row and print the character
		for (int row = 0; row < Board.ROWS; row++)
		{
			for (int col = 0; col < Board.COLS; col++)
			{
				if (pieces[row][col] == null)
					System.out.print(" " + Piece.EMPTY_PIECE);
				else
					System.out.print(" " + pieces[row][col]);
			}
			System.out.println();
		}
		// Print column numbers
		for (int col = 0; col < Board.COLS; col++)
		{
			System.out.print(" " + (col+1));
		}
		System.out.println();
	}
}